@@ -22,22 +22,23 @@
 #'  For more information, please refer to the homepage of this package:
 #'  \url{https://yuki-961004.github.io/binaryRL/}
 #'  
-#' @param estimate [character] 
+#' @param estimate [string] 
 #' 
 #'   Estimation method. Can be either \code{"MLE"} or \code{"MAP"}.
 #'   \itemize{
-#'     \item{\code{"MLE"}: (Default) Maximum Likelihood Estimation. This
-#'       method finds the parameter values that maximize the log-likelihood
+#'     \item{\strong{Maximum Likelihood Estimation} \code{"MLE"}: (Default): 
+#'       This method finds the parameter values that maximize the log-likelihood
 #'       of the data. A higher log-likelihood indicates that the parameters
 #'       provide a better explanation for the observed human behavior. In
 #'       other words, data simulated using these parameters would most
 #'       closely resemble the actual human data. This method does not
 #'       consider any prior information about the parameters.}
 #'       
-#'     \item{\code{"MAP"}: Maximum A Posteriori Estimation. This method
+#'     \item{\strong{Maximum A Posteriori Estimation} \code{"MAP"}: This method
 #'       finds the parameter values that maximize the posterior probability.
 #'       It is an iterative process based on the Expectation-Maximization
 #'       (EM) framework.
+#'       
 #'       \itemize{
 #'         \item{\strong{Initialization}: The process begins by assuming a
 #'           uniform distribution as the prior for each parameter, making the
@@ -50,8 +51,8 @@
 #'         \item{\strong{Re-estimation}: The parameters are then re-optimized
 #'           to maximize the updated posterior probability.}
 #'         \item{\strong{Convergence}: This cycle repeats until the posterior
-#'           probability converges or the maximum number of iterations
-#'           (specified by \code{iteration_g}) is reached.}
+#'           probability converges or the maximum number of iterations is 
+#'           reached.}
 #'       }
 #'       Using this method requires that the \code{priors} argument
 #'       be specified to define the initial prior distributions.
@@ -78,7 +79,7 @@
 #'     representation that likely drove the participant's decisions.
 #'   }
 #'   \item {
-#'    \strong{Off-Policy (SARSA): }
+#'    \strong{On-Policy (SARSA): }
 #'    In this mode, the target policy and the behavior policy are identical. 
 #'     The model first computes the selection probability for each option based 
 #'     on their current values. Critically, it then uses these probabilities to 
@@ -140,8 +141,9 @@
 #' 
 #' Upper bounds of free parameters
 #' 
-#' @param priors [list]
-#'   A list specifying the prior distributions for the model parameters.
+#' @param priors [List]
+#' 
+#'  A list specifying the prior distributions for the model parameters.
 #'   This argument is mandatory when using \code{estimate = "MAP"}.
 #'   There are two primary scenarios for its use:
 #'
@@ -152,8 +154,8 @@
 #'     \item{Configuration:}{
 #'       \itemize{
 #'         \item{Set \code{estimate = "MAP"}.}
-#'         \item{Provide a \code{list} defining your confident prior
-#'           distributions.}
+#'         \item{Provide \code{pirors} defining probability density function of
+#'          free parameters}
 #'         \item{Keep \code{iteration_g = 0} (the default).}
 #'       }
 #'     }
@@ -171,7 +173,7 @@
 #'       \itemize{
 #'         \item{Set \code{estimate = "MAP"}.}
 #'         \item{Specify a weak or non-informative initial prior, such as a
-#'           uniform distribution for all parameters.}
+#'           uniform distribution for all free parameters.}
 #'         \item{Set \code{iteration_g} to a value greater than 0.}
 #'       }
 #'     }
@@ -244,21 +246,21 @@
 #'   upper = c(1, 1, 1),
 #'   iteration = 10,
 #'   seed = 123,
-#'   algorithm = "L-BFGS-B"   # Gradient-Based (stats)
+#'   #algorithm = "L-BFGS-B"   # Gradient-Based (stats)
 #'   #algorithm = "GenSA"    # Simulated Annealing (GenSA)
 #'   #algorithm = "GA"       # Genetic Algorithm (GA)
 #'   #algorithm = "DEoptim"  # Differential Evolution (DEoptim)
 #'   #algorithm = "PSO"      # Particle Swarm Optimization (pso)
 #'   #algorithm = "Bayesian" # Bayesian Optimization (mlrMBO)
 #'   #algorithm = "CMA-ES"   # Covariance Matrix Adapting (cmaes)
-#'   #algorithm = c("NLOPT_GN_MLSL", "NLOPT_LN_BOBYQA")
+#'   algorithm = c("NLOPT_GN_MLSL", "NLOPT_LN_BOBYQA")
 #' )
 #' summary(binaryRL.res)
 #' }
 #' 
 optimize_para <- function(
-  policy = "off",
   estimate = "MLE",
+  policy = "off",
   
   data,
   id,
@@ -296,7 +298,7 @@ optimize_para <- function(
   environment(obj_func) <- binaryRL.env
   
   # 设定初始值
-  if (is.na(initial_params)){
+  if (length(initial_params) == 1 && is.na(initial_params)){
     initial_params <- lower + 1e-2
   }
   
